@@ -25,7 +25,7 @@ final readonly class RequiresOperatingSystem extends Metadata
      * @param int<0, 1>        $level
      * @param non-empty-string $operatingSystem
      */
-    public function __construct(int $level, string $operatingSystem)
+    protected function __construct(int $level, string $operatingSystem)
     {
         parent::__construct($level);
 
