@@ -7,7 +7,7 @@
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
-namespace Foo\Bar;
+namespace PHPUnit\TestFixture;
 
 final class Issue4232Test extends ParentIssue4232Test
 {
