@@ -10,6 +10,7 @@
 namespace PHPUnit\Framework;
 
 use PHPUnit\Framework\Attributes\CoversMethod;
+use PHPUnit\Framework\Attributes\DataProvider;
 use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\Attributes\TestDox;
 
@@ -18,9 +19,21 @@ use PHPUnit\Framework\Attributes\TestDox;
 #[Small]
 final class assertLessThanOrEqualTest extends TestCase
 {
-    public function testSucceedsWhenConstraintEvaluatesToTrue(): void
+    /**
+     * @return non-empty-list<array{0: int, 1: int}>
+     */
+    public static function successProvider(): array
     {
-        $this->assertLessThanOrEqual(2, 1);
+        return [
+            [2, 1],
+            [2, 2],
+        ];
+    }
+
+    #[DataProvider('successProvider')]
+    public function testSucceedsWhenConstraintEvaluatesToTrue(mixed $maximum, mixed $actual): void
+    {
+        $this->assertLessThanOrEqual($maximum, $actual);
     }
 
     public function testFailsWhenConstraintEvaluatesToFalse(): void
