@@ -20,18 +20,10 @@ use PHPUnit\Framework\Attributes\TestDox;
 final class StubTest extends TestDoubleTestCase
 {
     /**
-     * @psalm-param class-string $type
+     * @param class-string $type
      */
     protected function createTestDouble(string $type): object
     {
         return $this->createStub($type);
     }
-
-    /**
-     * @psalm-param list<class-string> $interfaces
-     */
-    protected function createTestDoubleForIntersection(array $interfaces): object
-    {
-        return $this->createStubForIntersectionOfInterfaces($interfaces);
-    }
 }
