@@ -9,6 +9,7 @@
  */
 namespace PHPUnit\TextUI\XmlConfiguration;
 
+use function count;
 use PHPUnit\Framework\Attributes\CoversClass;
 use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\TestCase;
@@ -18,12 +19,20 @@ use PHPUnit\Runner\Version;
 #[Small]
 final class SchemaFinderTest extends TestCase
 {
-    public function testFindsExistingSchemaForComposerInstallation(): void
+    public function testListsAvailableSchemas(): void
+    {
+        $schemas = (new SchemaFinder)->available();
+
+        $this->assertSame((new Version)->series(), $schemas[0]);
+        $this->assertSame('8.5', $schemas[count($schemas) - 1]);
+    }
+
+    public function testFindsExistingSchema(): void
     {
         $this->assertFileExists((new SchemaFinder)->find((new Version)->series()));
     }
 
-    public function testDoesNotFindNonExistentSchemaForComposerInstallation(): void
+    public function testDoesNotFindNonExistentSchema(): void
     {
         $this->expectException(CannotFindSchemaException::class);
 
